# coding: utf-8

from __future__ import absolute_import

import six
import re

from wallee.api_client import ApiClient

class SubscriptionProductVersionServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def activate(self, space_id, product_version_id, **kwargs):
        """activate

        This operation activates a new product version.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.activate(space_id, product_version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int product_version_id: The product version id identifies the product version which should be activated. (required)
        :return: SubscriptionProductVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.activate_with_http_info(space_id, product_version_id, **kwargs)
        else:
            (data) = self.activate_with_http_info(space_id, product_version_id, **kwargs)
            return data

    def activate_with_http_info(self, space_id, product_version_id, **kwargs):
        """activate

        This operation activates a new product version.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.activate_with_http_info(space_id, product_version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int product_version_id: The product version id identifies the product version which should be activated. (required)
        :return: SubscriptionProductVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'product_version_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method activate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `activate`")
        # verify the required parameter 'product_version_id' is set
        if ('product_version_id' not in params or
                params['product_version_id'] is None):
            raise ValueError("Missing the required parameter `product_version_id` when calling `activate`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'product_version_id' in params:
            query_params.append(('productVersionId', params['product_version_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription-product-version/activate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionProductVersion',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def count(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.count(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.count_with_http_info(space_id, **kwargs)
        else:
            (data) = self.count_with_http_info(space_id, **kwargs)
            return data

    def count_with_http_info(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.count_with_http_info(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'filter']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `count`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'filter' in params:
            body_params = params['filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription-product-version/count', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def create(self, space_id, entity, **kwargs):
        """Create

        Creates the entity with the given properties.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.create(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param SubscriptionProductVersionPending entity: The product version object with the properties which should be created. (required)
        :return: SubscriptionProductVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.create_with_http_info(space_id, entity, **kwargs)
        else:
            (data) = self.create_with_http_info(space_id, entity, **kwargs)
            return data

    def create_with_http_info(self, space_id, entity, **kwargs):
        """Create

        Creates the entity with the given properties.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.create_with_http_info(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param SubscriptionProductVersionPending entity: The product version object with the properties which should be created. (required)
        :return: SubscriptionProductVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'entity']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `create`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params or
                params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `create`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'entity' in params:
            body_params = params['entity']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription-product-version/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionProductVersion',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def read(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.read(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the product version which should be returned. (required)
        :return: SubscriptionProductVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.read_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.read_with_http_info(space_id, id, **kwargs)
            return data

    def read_with_http_info(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.read_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the product version which should be returned. (required)
        :return: SubscriptionProductVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `read`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `read`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription-product-version/read', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionProductVersion',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def search(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.search(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the product versions which are returned by the search. (required)
        :return: list[SubscriptionProductVersion]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.search_with_http_info(space_id, query, **kwargs)
        else:
            (data) = self.search_with_http_info(space_id, query, **kwargs)
            return data

    def search_with_http_info(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.search_with_http_info(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the product versions which are returned by the search. (required)
        :return: list[SubscriptionProductVersion]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'query']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `search`")
        # verify the required parameter 'query' is set
        if ('query' not in params or
                params['query'] is None):
            raise ValueError("Missing the required parameter `query` when calling `search`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query' in params:
            body_params = params['query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription-product-version/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SubscriptionProductVersion]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def update(self, space_id, entity, **kwargs):
        """Update

        This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.update(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param SubscriptionProductVersionPending entity: The product version object with all the properties which should be updated. The id and the version are required properties. (required)
        :return: SubscriptionProductVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.update_with_http_info(space_id, entity, **kwargs)
        else:
            (data) = self.update_with_http_info(space_id, entity, **kwargs)
            return data

    def update_with_http_info(self, space_id, entity, **kwargs):
        """Update

        This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.update_with_http_info(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param SubscriptionProductVersionPending entity: The product version object with all the properties which should be updated. The id and the version are required properties. (required)
        :return: SubscriptionProductVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'entity']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `update`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params or
                params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `update`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'entity' in params:
            body_params = params['entity']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription-product-version/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionProductVersion',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
import pprint
import six
from enum import Enum
from . import AbstractSubscriptionAffiliateUpdate


class SubscriptionAffiliateCreate(AbstractSubscriptionAffiliateUpdate):

    swagger_types = {
    
        'external_id': 'str',
        'reference': 'str',
    }

    attribute_map = {
        'external_id': 'externalId','reference': 'reference',
    }

    
    _external_id = None
    _reference = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.external_id = kwargs.get('external_id')

        self.reference = kwargs.get('reference')

        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def external_id(self):
        """Gets the external_id of this SubscriptionAffiliateCreate.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this SubscriptionAffiliateCreate.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this SubscriptionAffiliateCreate.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this SubscriptionAffiliateCreate.
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")

        self._external_id = external_id
    
    @property
    def reference(self):
        """Gets the reference of this SubscriptionAffiliateCreate.

            

        :return: The reference of this SubscriptionAffiliateCreate.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SubscriptionAffiliateCreate.

            

        :param reference: The reference of this SubscriptionAffiliateCreate.
        :type: str
        """
        if reference is None:
            raise ValueError("Invalid value for `reference`, must not be `None`")
        if reference is not None and len(reference) > 100:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `100`")
        if reference is not None and len(reference) < 3:
            raise ValueError("Invalid value for `reference`, length must be greater than or equal to `3`")

        self._reference = reference
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionAffiliateCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionAffiliateCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



import unittest

from constants import (
    API_CONFIG,
    SPACE_ID,
    get_transaction_create,
)

from wallee.api import (
    TransactionServiceApi,
    TransactionLightboxServiceApi
)


class TransactionLigthboxServiceTest(unittest.TestCase):
    """TransactionLigthboxServiceApi tests"""

    def setUp(self):
        self.transaction_service = TransactionServiceApi(API_CONFIG)
        self.transaction_lightbox_service = TransactionLightboxServiceApi(
            API_CONFIG)

    def tearDown(self):
        pass

    def test_javascript_url(self):
        """javascript_url() should create URL for use in Lightbox checkout flow javascript"""

        transaction_create = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        url = self.transaction_lightbox_service.javascript_url(
            space_id=SPACE_ID, id=transaction_create.id)

        self.assertTrue("securityToken" in url,
                        "URL must have proper format")


if __name__ == '__main__':
    unittest.main(failfast=True)



import unittest

from constants import (
    API_CONFIG,
    SPACE_ID,
    TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
    FAKE_CARD_DATA,
    get_transaction_create
)

from wallee.api import (
    TransactionServiceApi,
    CardProcessingServiceApi,
    TransactionCompletionServiceApi,
    RefundServiceApi
)

from wallee.models import (
    TransactionCompletionState,
    RefundCreate,
    RefundType,
    RefundState,
    EntityQuery,
    EntityQueryFilter,
    EntityQueryFilterType,
    CriteriaOperator
)


class RefundServiceTest(unittest.TestCase):
    """RefundServiceApi tests"""

    def setUp(self):
        self.transaction_service = TransactionServiceApi(API_CONFIG)
        self.transaction_completion_service = TransactionCompletionServiceApi(
            API_CONFIG)
        self.card_processing_service = CardProcessingServiceApi(API_CONFIG)
        self.refund_service = RefundServiceApi(API_CONFIG)

    def tearDown(self):
        pass

    def __get_refund_create(self, transaction):
        refund_create = RefundCreate(
            external_id=str(transaction.id),
            type=RefundType.MERCHANT_INITIATED_ONLINE,
            amount=transaction.authorization_amount,
            transaction=transaction.id,
            merchant_reference=transaction.merchant_reference
        )
        return refund_create

    def test_refund(self):
        """refund() should create a refund for transaction"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        transaction_completion = self.transaction_completion_service.complete_offline(
            space_id=SPACE_ID, id=transaction_processed.id)

        self.assertEqual(
            TransactionCompletionState.SUCCESSFUL,
            transaction_completion.state,
            "State must be SUCCESSFUL",
        )

        transaction_read = self.transaction_service.read(
            space_id=SPACE_ID, id=transaction_processed.id)

        refund = self.refund_service.refund(
            space_id=SPACE_ID, refund=self.__get_refund_create(transaction_read))

        self.assertEqual(
            RefundState.SUCCESSFUL,
            refund.state,
            "State must be SUCCESSFUL",
        )

    def test_read_not_found(self):
        """read_not_found() should read not found refund as none"""

        NOT_FOUND_REFUND_ID = 0

        refund_read = self.refund_service.read(
            space_id=SPACE_ID, id=NOT_FOUND_REFUND_ID)

        self.assertIsNone(refund_read, "Return data must be None.")

    def test_read(self):
        """read() should fetch refund details"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        transaction_completion = self.transaction_completion_service.complete_offline(
            space_id=SPACE_ID, id=transaction_processed.id)

        self.assertEqual(
            TransactionCompletionState.SUCCESSFUL,
            transaction_completion.state,
            "State must be SUCCESSFUL",
        )

        transaction_read = self.transaction_service.read(
            space_id=SPACE_ID, id=transaction_processed.id)

        refund = self.refund_service.refund(
            space_id=SPACE_ID, refund=self.__get_refund_create(transaction_read))

        self.assertEqual(
            RefundState.SUCCESSFUL,
            refund.state,
            "State must be SUCCESSFUL",
        )

        read_refund = self.refund_service.read(
            space_id=SPACE_ID, id=refund.id)

        self.assertIsNotNone(read_refund, "Return data must not be None.")

        self.assertEqual(
            refund.id,
            read_refund.id,
            "Refund ids must match",
        )

    def test_search(self):
        """search() should find a refund for a given criteria"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        transaction_completion = self.transaction_completion_service.complete_offline(
            space_id=SPACE_ID, id=transaction_processed.id)

        self.assertEqual(
            TransactionCompletionState.SUCCESSFUL,
            transaction_completion.state,
            "State must be SUCCESSFUL",
        )

        transaction_read = self.transaction_service.read(
            space_id=SPACE_ID, id=transaction_processed.id)

        refund = self.refund_service.refund(
            space_id=SPACE_ID, refund=self.__get_refund_create(transaction_read))

        self.assertEqual(
            RefundState.SUCCESSFUL,
            refund.state,
            "State must be SUCCESSFUL",
        )

        criteria = EntityQuery(
            filter=EntityQueryFilter(
                field_name="id",
                value=refund.id,
                type=EntityQueryFilterType.LEAF,
                operator=CriteriaOperator.EQUALS
            )
        )

        refunds_found = self.refund_service.search(
            SPACE_ID, query=criteria)

        self.assertEqual(1, len(refunds_found))
        for ref in refunds_found:
            self.assertEqual(
                refund.id,
                ref.id,
                "Refund ids must match",
            )

    def test_count(self):
        """count() should count refunds for a given criteria"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        transaction_completion = self.transaction_completion_service.complete_offline(
            space_id=SPACE_ID, id=transaction_processed.id)

        self.assertEqual(
            TransactionCompletionState.SUCCESSFUL,
            transaction_completion.state,
            "State must be SUCCESSFUL",
        )

        transaction_read = self.transaction_service.read(
            space_id=SPACE_ID, id=transaction_processed.id)

        refund = self.refund_service.refund(
            space_id=SPACE_ID, refund=self.__get_refund_create(transaction_read))

        self.assertEqual(
            RefundState.SUCCESSFUL,
            refund.state,
            "State must be SUCCESSFUL",
        )

        criteria = EntityQueryFilter(
            field_name="id",
            value=refund.id,
            type=EntityQueryFilterType.LEAF,
            operator=CriteriaOperator.EQUALS
        )

        count = self.refund_service.count(
            SPACE_ID, filter=criteria)

        self.assertEqual(1, count, "Should find 1 refund", )


if __name__ == "__main__":
    unittest.main(failfast=True)



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractShopifySubscriptionProductUpdate:

    swagger_types = {
    
        'absolute_price_adjustment': 'float',
        'billing_day_of_month': 'int',
        'billing_interval_amount': 'int',
        'billing_interval_unit': 'ShopifySubscriptionBillingIntervalUnit',
        'billing_weekday': 'ShopifySubscriptionWeekday',
        'fixed_price': 'float',
        'maximal_billing_cycles': 'int',
        'maximal_suspendable_cycles': 'int',
        'minimal_billing_cycles': 'int',
        'pricing_option': 'ShopifySubscriptionProductPricingOption',
        'relative_price_adjustment': 'float',
        'store_order_confirmation_email_enabled': 'bool',
        'subscriber_suspension_allowed': 'bool',
        'termination_billing_cycles': 'int',
    }

    attribute_map = {
        'absolute_price_adjustment': 'absolutePriceAdjustment','billing_day_of_month': 'billingDayOfMonth','billing_interval_amount': 'billingIntervalAmount','billing_interval_unit': 'billingIntervalUnit','billing_weekday': 'billingWeekday','fixed_price': 'fixedPrice','maximal_billing_cycles': 'maximalBillingCycles','maximal_suspendable_cycles': 'maximalSuspendableCycles','minimal_billing_cycles': 'minimalBillingCycles','pricing_option': 'pricingOption','relative_price_adjustment': 'relativePriceAdjustment','store_order_confirmation_email_enabled': 'storeOrderConfirmationEmailEnabled','subscriber_suspension_allowed': 'subscriberSuspensionAllowed','termination_billing_cycles': 'terminationBillingCycles',
    }

    
    _absolute_price_adjustment = None
    _billing_day_of_month = None
    _billing_interval_amount = None
    _billing_interval_unit = None
    _billing_weekday = None
    _fixed_price = None
    _maximal_billing_cycles = None
    _maximal_suspendable_cycles = None
    _minimal_billing_cycles = None
    _pricing_option = None
    _relative_price_adjustment = None
    _store_order_confirmation_email_enabled = None
    _subscriber_suspension_allowed = None
    _termination_billing_cycles = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.absolute_price_adjustment = kwargs.get('absolute_price_adjustment', None)
        self.billing_day_of_month = kwargs.get('billing_day_of_month', None)
        self.billing_interval_amount = kwargs.get('billing_interval_amount', None)
        self.billing_interval_unit = kwargs.get('billing_interval_unit', None)
        self.billing_weekday = kwargs.get('billing_weekday', None)
        self.fixed_price = kwargs.get('fixed_price', None)
        self.maximal_billing_cycles = kwargs.get('maximal_billing_cycles', None)
        self.maximal_suspendable_cycles = kwargs.get('maximal_suspendable_cycles', None)
        self.minimal_billing_cycles = kwargs.get('minimal_billing_cycles', None)
        self.pricing_option = kwargs.get('pricing_option', None)
        self.relative_price_adjustment = kwargs.get('relative_price_adjustment', None)
        self.store_order_confirmation_email_enabled = kwargs.get('store_order_confirmation_email_enabled', None)
        self.subscriber_suspension_allowed = kwargs.get('subscriber_suspension_allowed', None)
        self.termination_billing_cycles = kwargs.get('termination_billing_cycles', None)
        

    
    @property
    def absolute_price_adjustment(self):
        """Gets the absolute_price_adjustment of this AbstractShopifySubscriptionProductUpdate.

            

        :return: The absolute_price_adjustment of this AbstractShopifySubscriptionProductUpdate.
        :rtype: float
        """
        return self._absolute_price_adjustment

    @absolute_price_adjustment.setter
    def absolute_price_adjustment(self, absolute_price_adjustment):
        """Sets the absolute_price_adjustment of this AbstractShopifySubscriptionProductUpdate.

            

        :param absolute_price_adjustment: The absolute_price_adjustment of this AbstractShopifySubscriptionProductUpdate.
        :type: float
        """

        self._absolute_price_adjustment = absolute_price_adjustment
    
    @property
    def billing_day_of_month(self):
        """Gets the billing_day_of_month of this AbstractShopifySubscriptionProductUpdate.

            Define the day of the month on which the recurring orders should be created.

        :return: The billing_day_of_month of this AbstractShopifySubscriptionProductUpdate.
        :rtype: int
        """
        return self._billing_day_of_month

    @billing_day_of_month.setter
    def billing_day_of_month(self, billing_day_of_month):
        """Sets the billing_day_of_month of this AbstractShopifySubscriptionProductUpdate.

            Define the day of the month on which the recurring orders should be created.

        :param billing_day_of_month: The billing_day_of_month of this AbstractShopifySubscriptionProductUpdate.
        :type: int
        """

        self._billing_day_of_month = billing_day_of_month
    
    @property
    def billing_interval_amount(self):
        """Gets the billing_interval_amount of this AbstractShopifySubscriptionProductUpdate.

            

        :return: The billing_interval_amount of this AbstractShopifySubscriptionProductUpdate.
        :rtype: int
        """
        return self._billing_interval_amount

    @billing_interval_amount.setter
    def billing_interval_amount(self, billing_interval_amount):
        """Sets the billing_interval_amount of this AbstractShopifySubscriptionProductUpdate.

            

        :param billing_interval_amount: The billing_interval_amount of this AbstractShopifySubscriptionProductUpdate.
        :type: int
        """

        self._billing_interval_amount = billing_interval_amount
    
    @property
    def billing_interval_unit(self):
        """Gets the billing_interval_unit of this AbstractShopifySubscriptionProductUpdate.

            Define how frequently recurring orders should be created.

        :return: The billing_interval_unit of this AbstractShopifySubscriptionProductUpdate.
        :rtype: ShopifySubscriptionBillingIntervalUnit
        """
        return self._billing_interval_unit

    @billing_interval_unit.setter
    def billing_interval_unit(self, billing_interval_unit):
        """Sets the billing_interval_unit of this AbstractShopifySubscriptionProductUpdate.

            Define how frequently recurring orders should be created.

        :param billing_interval_unit: The billing_interval_unit of this AbstractShopifySubscriptionProductUpdate.
        :type: ShopifySubscriptionBillingIntervalUnit
        """

        self._billing_interval_unit = billing_interval_unit
    
    @property
    def billing_weekday(self):
        """Gets the billing_weekday of this AbstractShopifySubscriptionProductUpdate.

            Define the weekday on which the recurring orders should be created.

        :return: The billing_weekday of this AbstractShopifySubscriptionProductUpdate.
        :rtype: ShopifySubscriptionWeekday
        """
        return self._billing_weekday

    @billing_weekday.setter
    def billing_weekday(self, billing_weekday):
        """Sets the billing_weekday of this AbstractShopifySubscriptionProductUpdate.

            Define the weekday on which the recurring orders should be created.

        :param billing_weekday: The billing_weekday of this AbstractShopifySubscriptionProductUpdate.
        :type: ShopifySubscriptionWeekday
        """

        self._billing_weekday = billing_weekday
    
    @property
    def fixed_price(self):
        """Gets the fixed_price of this AbstractShopifySubscriptionProductUpdate.

            

        :return: The fixed_price of this AbstractShopifySubscriptionProductUpdate.
        :rtype: float
        """
        return self._fixed_price

    @fixed_price.setter
    def fixed_price(self, fixed_price):
        """Sets the fixed_price of this AbstractShopifySubscriptionProductUpdate.

            

        :param fixed_price: The fixed_price of this AbstractShopifySubscriptionProductUpdate.
        :type: float
        """

        self._fixed_price = fixed_price
    
    @property
    def maximal_billing_cycles(self):
        """Gets the maximal_billing_cycles of this AbstractShopifySubscriptionProductUpdate.

            Define the maximum number of orders the subscription will run for.

        :return: The maximal_billing_cycles of this AbstractShopifySubscriptionProductUpdate.
        :rtype: int
        """
        return self._maximal_billing_cycles

    @maximal_billing_cycles.setter
    def maximal_billing_cycles(self, maximal_billing_cycles):
        """Sets the maximal_billing_cycles of this AbstractShopifySubscriptionProductUpdate.

            Define the maximum number of orders the subscription will run for.

        :param maximal_billing_cycles: The maximal_billing_cycles of this AbstractShopifySubscriptionProductUpdate.
        :type: int
        """

        self._maximal_billing_cycles = maximal_billing_cycles
    
    @property
    def maximal_suspendable_cycles(self):
        """Gets the maximal_suspendable_cycles of this AbstractShopifySubscriptionProductUpdate.

            Define the maximum number of orders the subscription can be suspended for at a time.

        :return: The maximal_suspendable_cycles of this AbstractShopifySubscriptionProductUpdate.
        :rtype: int
        """
        return self._maximal_suspendable_cycles

    @maximal_suspendable_cycles.setter
    def maximal_suspendable_cycles(self, maximal_suspendable_cycles):
        """Sets the maximal_suspendable_cycles of this AbstractShopifySubscriptionProductUpdate.

            Define the maximum number of orders the subscription can be suspended for at a time.

        :param maximal_suspendable_cycles: The maximal_suspendable_cycles of this AbstractShopifySubscriptionProductUpdate.
        :type: int
        """

        self._maximal_suspendable_cycles = maximal_suspendable_cycles
    
    @property
    def minimal_billing_cycles(self):
        """Gets the minimal_billing_cycles of this AbstractShopifySubscriptionProductUpdate.

            Define the minimal number of orders the subscription will run for.

        :return: The minimal_billing_cycles of this AbstractShopifySubscriptionProductUpdate.
        :rtype: int
        """
        return self._minimal_billing_cycles

    @minimal_billing_cycles.setter
    def minimal_billing_cycles(self, minimal_billing_cycles):
        """Sets the minimal_billing_cycles of this AbstractShopifySubscriptionProductUpdate.

            Define the minimal number of orders the subscription will run for.

        :param minimal_billing_cycles: The minimal_billing_cycles of this AbstractShopifySubscriptionProductUpdate.
        :type: int
        """

        self._minimal_billing_cycles = minimal_billing_cycles
    
    @property
    def pricing_option(self):
        """Gets the pricing_option of this AbstractShopifySubscriptionProductUpdate.

            

        :return: The pricing_option of this AbstractShopifySubscriptionProductUpdate.
        :rtype: ShopifySubscriptionProductPricingOption
        """
        return self._pricing_option

    @pricing_option.setter
    def pricing_option(self, pricing_option):
        """Sets the pricing_option of this AbstractShopifySubscriptionProductUpdate.

            

        :param pricing_option: The pricing_option of this AbstractShopifySubscriptionProductUpdate.
        :type: ShopifySubscriptionProductPricingOption
        """

        self._pricing_option = pricing_option
    
    @property
    def relative_price_adjustment(self):
        """Gets the relative_price_adjustment of this AbstractShopifySubscriptionProductUpdate.

            

        :return: The relative_price_adjustment of this AbstractShopifySubscriptionProductUpdate.
        :rtype: float
        """
        return self._relative_price_adjustment

    @relative_price_adjustment.setter
    def relative_price_adjustment(self, relative_price_adjustment):
        """Sets the relative_price_adjustment of this AbstractShopifySubscriptionProductUpdate.

            

        :param relative_price_adjustment: The relative_price_adjustment of this AbstractShopifySubscriptionProductUpdate.
        :type: float
        """

        self._relative_price_adjustment = relative_price_adjustment
    
    @property
    def store_order_confirmation_email_enabled(self):
        """Gets the store_order_confirmation_email_enabled of this AbstractShopifySubscriptionProductUpdate.

            Define whether the order confirmation email of the Shopify shop is sent to the customer for recurring orders.

        :return: The store_order_confirmation_email_enabled of this AbstractShopifySubscriptionProductUpdate.
        :rtype: bool
        """
        return self._store_order_confirmation_email_enabled

    @store_order_confirmation_email_enabled.setter
    def store_order_confirmation_email_enabled(self, store_order_confirmation_email_enabled):
        """Sets the store_order_confirmation_email_enabled of this AbstractShopifySubscriptionProductUpdate.

            Define whether the order confirmation email of the Shopify shop is sent to the customer for recurring orders.

        :param store_order_confirmation_email_enabled: The store_order_confirmation_email_enabled of this AbstractShopifySubscriptionProductUpdate.
        :type: bool
        """

        self._store_order_confirmation_email_enabled = store_order_confirmation_email_enabled
    
    @property
    def subscriber_suspension_allowed(self):
        """Gets the subscriber_suspension_allowed of this AbstractShopifySubscriptionProductUpdate.

            Define whether the customer is allowed to suspend subscriptions.

        :return: The subscriber_suspension_allowed of this AbstractShopifySubscriptionProductUpdate.
        :rtype: bool
        """
        return self._subscriber_suspension_allowed

    @subscriber_suspension_allowed.setter
    def subscriber_suspension_allowed(self, subscriber_suspension_allowed):
        """Sets the subscriber_suspension_allowed of this AbstractShopifySubscriptionProductUpdate.

            Define whether the customer is allowed to suspend subscriptions.

        :param subscriber_suspension_allowed: The subscriber_suspension_allowed of this AbstractShopifySubscriptionProductUpdate.
        :type: bool
        """

        self._subscriber_suspension_allowed = subscriber_suspension_allowed
    
    @property
    def termination_billing_cycles(self):
        """Gets the termination_billing_cycles of this AbstractShopifySubscriptionProductUpdate.

            Define the number of orders the subscription will keep running for after its termination has been requested.

        :return: The termination_billing_cycles of this AbstractShopifySubscriptionProductUpdate.
        :rtype: int
        """
        return self._termination_billing_cycles

    @termination_billing_cycles.setter
    def termination_billing_cycles(self, termination_billing_cycles):
        """Sets the termination_billing_cycles of this AbstractShopifySubscriptionProductUpdate.

            Define the number of orders the subscription will keep running for after its termination has been requested.

        :param termination_billing_cycles: The termination_billing_cycles of this AbstractShopifySubscriptionProductUpdate.
        :type: int
        """

        self._termination_billing_cycles = termination_billing_cycles
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractShopifySubscriptionProductUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractShopifySubscriptionProductUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class InstallmentPaymentSlice(TransactionAwareEntity):

    swagger_types = {
    
        'charge_on': 'datetime',
        'created_on': 'datetime',
        'installment_payment': 'InstallmentPayment',
        'line_items': 'list[LineItem]',
        'planned_purge_date': 'datetime',
        'state': 'InstallmentPaymentSliceState',
        'transaction': 'Transaction',
        'version': 'int',
    }

    attribute_map = {
        'charge_on': 'chargeOn','created_on': 'createdOn','installment_payment': 'installmentPayment','line_items': 'lineItems','planned_purge_date': 'plannedPurgeDate','state': 'state','transaction': 'transaction','version': 'version',
    }

    
    _charge_on = None
    _created_on = None
    _installment_payment = None
    _line_items = None
    _planned_purge_date = None
    _state = None
    _transaction = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.charge_on = kwargs.get('charge_on', None)
        self.created_on = kwargs.get('created_on', None)
        self.installment_payment = kwargs.get('installment_payment', None)
        self.line_items = kwargs.get('line_items', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.transaction = kwargs.get('transaction', None)
        self.version = kwargs.get('version', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def charge_on(self):
        """Gets the charge_on of this InstallmentPaymentSlice.

            

        :return: The charge_on of this InstallmentPaymentSlice.
        :rtype: datetime
        """
        return self._charge_on

    @charge_on.setter
    def charge_on(self, charge_on):
        """Sets the charge_on of this InstallmentPaymentSlice.

            

        :param charge_on: The charge_on of this InstallmentPaymentSlice.
        :type: datetime
        """

        self._charge_on = charge_on
    
    @property
    def created_on(self):
        """Gets the created_on of this InstallmentPaymentSlice.

            The date and time when the object was created.

        :return: The created_on of this InstallmentPaymentSlice.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this InstallmentPaymentSlice.

            The date and time when the object was created.

        :param created_on: The created_on of this InstallmentPaymentSlice.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def installment_payment(self):
        """Gets the installment_payment of this InstallmentPaymentSlice.

            

        :return: The installment_payment of this InstallmentPaymentSlice.
        :rtype: InstallmentPayment
        """
        return self._installment_payment

    @installment_payment.setter
    def installment_payment(self, installment_payment):
        """Sets the installment_payment of this InstallmentPaymentSlice.

            

        :param installment_payment: The installment_payment of this InstallmentPaymentSlice.
        :type: InstallmentPayment
        """

        self._installment_payment = installment_payment
    
    @property
    def line_items(self):
        """Gets the line_items of this InstallmentPaymentSlice.

            

        :return: The line_items of this InstallmentPaymentSlice.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this InstallmentPaymentSlice.

            

        :param line_items: The line_items of this InstallmentPaymentSlice.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this InstallmentPaymentSlice.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this InstallmentPaymentSlice.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this InstallmentPaymentSlice.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this InstallmentPaymentSlice.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this InstallmentPaymentSlice.

            The object's current state.

        :return: The state of this InstallmentPaymentSlice.
        :rtype: InstallmentPaymentSliceState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InstallmentPaymentSlice.

            The object's current state.

        :param state: The state of this InstallmentPaymentSlice.
        :type: InstallmentPaymentSliceState
        """

        self._state = state
    
    @property
    def transaction(self):
        """Gets the transaction of this InstallmentPaymentSlice.

            

        :return: The transaction of this InstallmentPaymentSlice.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this InstallmentPaymentSlice.

            

        :param transaction: The transaction of this InstallmentPaymentSlice.
        :type: Transaction
        """

        self._transaction = transaction
    
    @property
    def version(self):
        """Gets the version of this InstallmentPaymentSlice.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this InstallmentPaymentSlice.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InstallmentPaymentSlice.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this InstallmentPaymentSlice.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(InstallmentPaymentSlice, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, InstallmentPaymentSlice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class PaymentLinkAddressHandlingMode(Enum):
    
    NOT_REQUIRED = "NOT_REQUIRED"
    REQUIRED_IN_URL = "REQUIRED_IN_URL"
    REQUIRED_ON_PAYMENT_PAGE = "REQUIRED_ON_PAYMENT_PAGE"




# coding: utf-8
from enum import Enum, unique


@unique
class TransactionState(Enum):
    
    CREATE = "CREATE"
    PENDING = "PENDING"
    CONFIRMED = "CONFIRMED"
    PROCESSING = "PROCESSING"
    FAILED = "FAILED"
    AUTHORIZED = "AUTHORIZED"
    VOIDED = "VOIDED"
    COMPLETED = "COMPLETED"
    FULFILL = "FULFILL"
    DECLINE = "DECLINE"




# coding: utf-8
from enum import Enum, unique


@unique
class ShopifySubscriptionProductPricingOption(Enum):
    
    CURRENT_PRICE = "CURRENT_PRICE"
    ORIGINAL_PRICE = "ORIGINAL_PRICE"
    FIXED_PRICE = "FIXED_PRICE"
    RELATIVE_ADJUSTMENT = "RELATIVE_ADJUSTMENT"
    ABSOLUTE_ADJUSTMENT = "ABSOLUTE_ADJUSTMENT"




# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAdjustment:

    swagger_types = {
    
        'amount_excluding_tax': 'float',
        'amount_including_tax': 'float',
        'rate_in_percentage': 'float',
        'tax': 'Tax',
        'type': 'int',
    }

    attribute_map = {
        'amount_excluding_tax': 'amountExcludingTax','amount_including_tax': 'amountIncludingTax','rate_in_percentage': 'rateInPercentage','tax': 'tax','type': 'type',
    }

    
    _amount_excluding_tax = None
    _amount_including_tax = None
    _rate_in_percentage = None
    _tax = None
    _type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount_excluding_tax = kwargs.get('amount_excluding_tax', None)
        self.amount_including_tax = kwargs.get('amount_including_tax', None)
        self.rate_in_percentage = kwargs.get('rate_in_percentage', None)
        self.tax = kwargs.get('tax', None)
        self.type = kwargs.get('type', None)
        

    
    @property
    def amount_excluding_tax(self):
        """Gets the amount_excluding_tax of this PaymentAdjustment.

            

        :return: The amount_excluding_tax of this PaymentAdjustment.
        :rtype: float
        """
        return self._amount_excluding_tax

    @amount_excluding_tax.setter
    def amount_excluding_tax(self, amount_excluding_tax):
        """Sets the amount_excluding_tax of this PaymentAdjustment.

            

        :param amount_excluding_tax: The amount_excluding_tax of this PaymentAdjustment.
        :type: float
        """

        self._amount_excluding_tax = amount_excluding_tax
    
    @property
    def amount_including_tax(self):
        """Gets the amount_including_tax of this PaymentAdjustment.

            The total amount of this adjustment including taxes.

        :return: The amount_including_tax of this PaymentAdjustment.
        :rtype: float
        """
        return self._amount_including_tax

    @amount_including_tax.setter
    def amount_including_tax(self, amount_including_tax):
        """Sets the amount_including_tax of this PaymentAdjustment.

            The total amount of this adjustment including taxes.

        :param amount_including_tax: The amount_including_tax of this PaymentAdjustment.
        :type: float
        """

        self._amount_including_tax = amount_including_tax
    
    @property
    def rate_in_percentage(self):
        """Gets the rate_in_percentage of this PaymentAdjustment.

            The rate in percentage is the rate on which the adjustment amount was calculated with.

        :return: The rate_in_percentage of this PaymentAdjustment.
        :rtype: float
        """
        return self._rate_in_percentage

    @rate_in_percentage.setter
    def rate_in_percentage(self, rate_in_percentage):
        """Sets the rate_in_percentage of this PaymentAdjustment.

            The rate in percentage is the rate on which the adjustment amount was calculated with.

        :param rate_in_percentage: The rate_in_percentage of this PaymentAdjustment.
        :type: float
        """

        self._rate_in_percentage = rate_in_percentage
    
    @property
    def tax(self):
        """Gets the tax of this PaymentAdjustment.

            

        :return: The tax of this PaymentAdjustment.
        :rtype: Tax
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this PaymentAdjustment.

            

        :param tax: The tax of this PaymentAdjustment.
        :type: Tax
        """

        self._tax = tax
    
    @property
    def type(self):
        """Gets the type of this PaymentAdjustment.

            

        :return: The type of this PaymentAdjustment.
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PaymentAdjustment.

            

        :param type: The type of this PaymentAdjustment.
        :type: int
        """

        self._type = type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAdjustment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAdjustment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class CustomersPresence(Enum):
    
    NOT_PRESENT = "NOT_PRESENT"
    VIRTUAL_PRESENT = "VIRTUAL_PRESENT"
    PHYSICAL_PRESENT = "PHYSICAL_PRESENT"




# coding: utf-8
from enum import Enum, unique


@unique
class ShopifySubscriptionBillingIntervalUnit(Enum):
    
    MINUTES = "MINUTES"
    HOURS = "HOURS"
    DAYS = "DAYS"
    WEEKS = "WEEKS"
    MONTHS = "MONTHS"
    YEARS = "YEARS"




# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppCompletionUpdateRequest:

    swagger_types = {
    
        'completion_id': 'int',
        'failure_reason_id': 'int',
        'reference': 'str',
        'target_state': 'PaymentAppCompletionTargetState',
    }

    attribute_map = {
        'completion_id': 'completionId','failure_reason_id': 'failureReasonId','reference': 'reference','target_state': 'targetState',
    }

    
    _completion_id = None
    _failure_reason_id = None
    _reference = None
    _target_state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.completion_id = kwargs.get('completion_id', None)
        self.failure_reason_id = kwargs.get('failure_reason_id', None)
        self.reference = kwargs.get('reference', None)
        self.target_state = kwargs.get('target_state', None)
        

    
    @property
    def completion_id(self):
        """Gets the completion_id of this PaymentAppCompletionUpdateRequest.

            This is the ID of the completion that should be updated.

        :return: The completion_id of this PaymentAppCompletionUpdateRequest.
        :rtype: int
        """
        return self._completion_id

    @completion_id.setter
    def completion_id(self, completion_id):
        """Sets the completion_id of this PaymentAppCompletionUpdateRequest.

            This is the ID of the completion that should be updated.

        :param completion_id: The completion_id of this PaymentAppCompletionUpdateRequest.
        :type: int
        """

        self._completion_id = completion_id
    
    @property
    def failure_reason_id(self):
        """Gets the failure_reason_id of this PaymentAppCompletionUpdateRequest.

            The failure reason indicates why the completion failed. It is required when the target state is FAILED.

        :return: The failure_reason_id of this PaymentAppCompletionUpdateRequest.
        :rtype: int
        """
        return self._failure_reason_id

    @failure_reason_id.setter
    def failure_reason_id(self, failure_reason_id):
        """Sets the failure_reason_id of this PaymentAppCompletionUpdateRequest.

            The failure reason indicates why the completion failed. It is required when the target state is FAILED.

        :param failure_reason_id: The failure_reason_id of this PaymentAppCompletionUpdateRequest.
        :type: int
        """

        self._failure_reason_id = failure_reason_id
    
    @property
    def reference(self):
        """Gets the reference of this PaymentAppCompletionUpdateRequest.

            The reference identifies the completion within the systems of the external service provider. It is required when the target state is SUCCESSFUL.

        :return: The reference of this PaymentAppCompletionUpdateRequest.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this PaymentAppCompletionUpdateRequest.

            The reference identifies the completion within the systems of the external service provider. It is required when the target state is SUCCESSFUL.

        :param reference: The reference of this PaymentAppCompletionUpdateRequest.
        :type: str
        """
        if reference is not None and len(reference) > 100:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `100`")

        self._reference = reference
    
    @property
    def target_state(self):
        """Gets the target_state of this PaymentAppCompletionUpdateRequest.

            The target state defines the state into which the completion should be switched into. Once the completion changed the state it will not be possible to change it again.

        :return: The target_state of this PaymentAppCompletionUpdateRequest.
        :rtype: PaymentAppCompletionTargetState
        """
        return self._target_state

    @target_state.setter
    def target_state(self, target_state):
        """Sets the target_state of this PaymentAppCompletionUpdateRequest.

            The target state defines the state into which the completion should be switched into. Once the completion changed the state it will not be possible to change it again.

        :param target_state: The target_state of this PaymentAppCompletionUpdateRequest.
        :type: PaymentAppCompletionTargetState
        """

        self._target_state = target_state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppCompletionUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppCompletionUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class FailureCategory(Enum):
    
    TEMPORARY_ISSUE = "TEMPORARY_ISSUE"
    INTERNAL = "INTERNAL"
    END_USER = "END_USER"
    CONFIGURATION = "CONFIGURATION"
    DEVELOPER = "DEVELOPER"




# coding: utf-8
from enum import Enum, unique


@unique
class SubscriptionProductVersionState(Enum):
    
    PENDING = "PENDING"
    ACTIVE = "ACTIVE"
    OBSOLETE = "OBSOLETE"
    RETIRING = "RETIRING"
    RETIRED = "RETIRED"




# coding: utf-8
import pprint
import six
from enum import Enum



class CustomerAddress:

    swagger_types = {
    
        'address': 'CustomerPostalAddress',
        'address_type': 'CustomerAddressType',
        'created_on': 'datetime',
        'customer': 'Customer',
        'default_address': 'bool',
        'id': 'int',
        'linked_space_id': 'int',
        'version': 'int',
    }

    attribute_map = {
        'address': 'address','address_type': 'addressType','created_on': 'createdOn','customer': 'customer','default_address': 'defaultAddress','id': 'id','linked_space_id': 'linkedSpaceId','version': 'version',
    }

    
    _address = None
    _address_type = None
    _created_on = None
    _customer = None
    _default_address = None
    _id = None
    _linked_space_id = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.address = kwargs.get('address', None)
        self.address_type = kwargs.get('address_type', None)
        self.created_on = kwargs.get('created_on', None)
        self.customer = kwargs.get('customer', None)
        self.default_address = kwargs.get('default_address', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def address(self):
        """Gets the address of this CustomerAddress.

            The actual postal address.

        :return: The address of this CustomerAddress.
        :rtype: CustomerPostalAddress
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this CustomerAddress.

            The actual postal address.

        :param address: The address of this CustomerAddress.
        :type: CustomerPostalAddress
        """

        self._address = address
    
    @property
    def address_type(self):
        """Gets the address_type of this CustomerAddress.

            Whether the address is for billing or shipping or both.

        :return: The address_type of this CustomerAddress.
        :rtype: CustomerAddressType
        """
        return self._address_type

    @address_type.setter
    def address_type(self, address_type):
        """Sets the address_type of this CustomerAddress.

            Whether the address is for billing or shipping or both.

        :param address_type: The address_type of this CustomerAddress.
        :type: CustomerAddressType
        """

        self._address_type = address_type
    
    @property
    def created_on(self):
        """Gets the created_on of this CustomerAddress.

            The date and time when the object was created.

        :return: The created_on of this CustomerAddress.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this CustomerAddress.

            The date and time when the object was created.

        :param created_on: The created_on of this CustomerAddress.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def customer(self):
        """Gets the customer of this CustomerAddress.

            The customer that the object belongs to.

        :return: The customer of this CustomerAddress.
        :rtype: Customer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this CustomerAddress.

            The customer that the object belongs to.

        :param customer: The customer of this CustomerAddress.
        :type: Customer
        """

        self._customer = customer
    
    @property
    def default_address(self):
        """Gets the default_address of this CustomerAddress.

            Whether this is the customer's default address.

        :return: The default_address of this CustomerAddress.
        :rtype: bool
        """
        return self._default_address

    @default_address.setter
    def default_address(self, default_address):
        """Sets the default_address of this CustomerAddress.

            Whether this is the customer's default address.

        :param default_address: The default_address of this CustomerAddress.
        :type: bool
        """

        self._default_address = default_address
    
    @property
    def id(self):
        """Gets the id of this CustomerAddress.

            A unique identifier for the object.

        :return: The id of this CustomerAddress.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CustomerAddress.

            A unique identifier for the object.

        :param id: The id of this CustomerAddress.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this CustomerAddress.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this CustomerAddress.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this CustomerAddress.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this CustomerAddress.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def version(self):
        """Gets the version of this CustomerAddress.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this CustomerAddress.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CustomerAddress.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this CustomerAddress.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(CustomerAddress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, CustomerAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class InstallmentPaymentState(Enum):
    
    CREATE = "CREATE"
    CONFIRMED = "CONFIRMED"
    AUTHORIZED = "AUTHORIZED"
    REJECTED = "REJECTED"
    COMPLETED = "COMPLETED"
    RUNNING = "RUNNING"
    DONE = "DONE"
    DEFAULTED = "DEFAULTED"




import unittest
from unittest.mock import patch

from constants import (
    API_CONFIG
)
from wallee.api import (
    WebhookEncryptionServiceApi
)
from wallee.models import (
    WebhookEncryptionPublicKey
)

CONTENT_TO_VERIFY = ('{"entityId":11,"eventId":35,"listenerEntityId":1472041829003,'
                     '"listenerEntityTechnicalName":"Transaction","spaceId":1,"state":"PROCESSING",'
                     '"timestamp":"2023-12-19T13:43:35+0000","webhookListenerId":2}')

SIGNATURE_HEADER = ("algorithm=SHA256withECDSA, keyId=ab3b774e-770e-4644-9b51-885d71f973e5, "
                    "signature=MEYCIQCTzbMrMsOAC6T57T9kQTb1iGZVg2R7n6pY9A4ML4P31gIhAIOoav8cG8x0jpRWQztqSJIC8gXWKq+4DuENEySvmMYf")

PUBLIC_KEY_ID = "ab3b774e-770e-4644-9b51-885d71f973e5"

VALID_ENCODED_PUBLIC_KEY = "MFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEdWq7ZBGsjUzhBO3e6mzUBLpjpV3TQw1bL1rk3ocjn5C5qne7TY0OBBhiWgaPtWlvUcqASz903vtfeSTQma+SBA=="


class WebhookEncryptionServiceTest(unittest.TestCase):
    """WebhookEncryptionServiceApi tests"""

    def setUp(self):
        self.webhook_encryption_service = WebhookEncryptionServiceApi(API_CONFIG)

    def tearDown(self):
        pass

    @patch('wallee.api.WebhookEncryptionServiceApi.read')
    def test_validate_valid_content_and_signature(self, mock_webhook_encryption_service_read):
        """validate_valid_content_and_signature() should validate correct content and signature"""

        mock_webhook_encryption_service_read.return_value = (
            WebhookEncryptionPublicKey(id=1, public_key=VALID_ENCODED_PUBLIC_KEY))

        is_content_valid = self.webhook_encryption_service.is_content_valid(SIGNATURE_HEADER, CONTENT_TO_VERIFY)

        mock_webhook_encryption_service_read.assert_called_once()
        self.assertIsNotNone(is_content_valid, "Return webhook encryption validation marker must not be None.")
        self.assertTrue(is_content_valid, "The webhook encryption content and signature must be valid.")

    @patch('wallee.api.WebhookEncryptionServiceApi.read')
    def test_read_webhook_encryption_not_found(self, mock_webhook_encryption_service_read):
        """read_webhook_encryption_not_found() should fail when webhook encryption public key is none """

        mock_webhook_encryption_service_read.return_value = None

        with self.assertRaises(ValueError) as context:
            self.webhook_encryption_service.is_content_valid(SIGNATURE_HEADER, CONTENT_TO_VERIFY)

        self.assertEqual(str(context.exception), f"Could not find public key with id {PUBLIC_KEY_ID}")

        mock_webhook_encryption_service_read.assert_called_once()

    @patch('wallee.api.WebhookEncryptionServiceApi.read')
    def test_validate_invalid_signature_header(self, mock_webhook_encryption_service_read):
        """validate_invalid_signature_header() should fail when signature header is invalid """

        mock_webhook_encryption_service_read.return_value = (
            WebhookEncryptionPublicKey(id=1, public_key=VALID_ENCODED_PUBLIC_KEY))

        invalid_signature_header = "algorithm=SHA256withECDSA, keyId=ab3b774e-770e-4644-9b51-885d71f973e5"

        with self.assertRaises(ValueError) as context:
            self.webhook_encryption_service.is_content_valid(invalid_signature_header, CONTENT_TO_VERIFY)

        self.assertEqual(str(context.exception), "Invalid webhook signature header. Expected format: "
                                                 "'algorithm=<algorithm>, keyId=<keyId>, signature=<signature>'")


if __name__ == "__main__":
    unittest.main(failfast=True)



# coding: utf-8
import pprint
import six
from enum import Enum



class ProductMeteredFee:

    swagger_types = {
    
        'component': 'SubscriptionProductComponent',
        'description': 'dict(str, str)',
        'id': 'int',
        'linked_space_id': 'int',
        'metric': 'SubscriptionMetric',
        'name': 'dict(str, str)',
        'tier_pricing': 'ProductMeteredTierPricing',
        'type': 'ProductFeeType',
        'version': 'int',
    }

    attribute_map = {
        'component': 'component','description': 'description','id': 'id','linked_space_id': 'linkedSpaceId','metric': 'metric','name': 'name','tier_pricing': 'tierPricing','type': 'type','version': 'version',
    }

    
    _component = None
    _description = None
    _id = None
    _linked_space_id = None
    _metric = None
    _name = None
    _tier_pricing = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.component = kwargs.get('component', None)
        self.description = kwargs.get('description', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.metric = kwargs.get('metric', None)
        self.name = kwargs.get('name', None)
        self.tier_pricing = kwargs.get('tier_pricing', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def component(self):
        """Gets the component of this ProductMeteredFee.

            

        :return: The component of this ProductMeteredFee.
        :rtype: SubscriptionProductComponent
        """
        return self._component

    @component.setter
    def component(self, component):
        """Sets the component of this ProductMeteredFee.

            

        :param component: The component of this ProductMeteredFee.
        :type: SubscriptionProductComponent
        """

        self._component = component
    
    @property
    def description(self):
        """Gets the description of this ProductMeteredFee.

            The description of a component fee describes the fee to the subscriber. The description may be shown in documents or on certain user interfaces.

        :return: The description of this ProductMeteredFee.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProductMeteredFee.

            The description of a component fee describes the fee to the subscriber. The description may be shown in documents or on certain user interfaces.

        :param description: The description of this ProductMeteredFee.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def id(self):
        """Gets the id of this ProductMeteredFee.

            A unique identifier for the object.

        :return: The id of this ProductMeteredFee.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProductMeteredFee.

            A unique identifier for the object.

        :param id: The id of this ProductMeteredFee.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this ProductMeteredFee.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this ProductMeteredFee.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this ProductMeteredFee.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this ProductMeteredFee.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def metric(self):
        """Gets the metric of this ProductMeteredFee.

            

        :return: The metric of this ProductMeteredFee.
        :rtype: SubscriptionMetric
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this ProductMeteredFee.

            

        :param metric: The metric of this ProductMeteredFee.
        :type: SubscriptionMetric
        """

        self._metric = metric
    
    @property
    def name(self):
        """Gets the name of this ProductMeteredFee.

            The name of the fee should describe for the subscriber in few words for what the fee is for.

        :return: The name of this ProductMeteredFee.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProductMeteredFee.

            The name of the fee should describe for the subscriber in few words for what the fee is for.

        :param name: The name of this ProductMeteredFee.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def tier_pricing(self):
        """Gets the tier_pricing of this ProductMeteredFee.

            The tier pricing determines the calculation method of the tiers. The prices of the different tiers can be applied in different ways. The tier pricing controls this calculation.

        :return: The tier_pricing of this ProductMeteredFee.
        :rtype: ProductMeteredTierPricing
        """
        return self._tier_pricing

    @tier_pricing.setter
    def tier_pricing(self, tier_pricing):
        """Sets the tier_pricing of this ProductMeteredFee.

            The tier pricing determines the calculation method of the tiers. The prices of the different tiers can be applied in different ways. The tier pricing controls this calculation.

        :param tier_pricing: The tier_pricing of this ProductMeteredFee.
        :type: ProductMeteredTierPricing
        """

        self._tier_pricing = tier_pricing
    
    @property
    def type(self):
        """Gets the type of this ProductMeteredFee.

            

        :return: The type of this ProductMeteredFee.
        :rtype: ProductFeeType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ProductMeteredFee.

            

        :param type: The type of this ProductMeteredFee.
        :type: ProductFeeType
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this ProductMeteredFee.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this ProductMeteredFee.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ProductMeteredFee.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this ProductMeteredFee.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ProductMeteredFee, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ProductMeteredFee):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class AccountState(Enum):
    
    CREATE = "CREATE"
    RESTRICTED_ACTIVE = "RESTRICTED_ACTIVE"
    ACTIVE = "ACTIVE"
    INACTIVE = "INACTIVE"
    DELETING = "DELETING"
    DELETED = "DELETED"




# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppConnectorCreationRequest:

    swagger_types = {
    
        'authorization_timeout_in_minutes': 'int',
        'completion_configuration': 'PaymentAppCompletionConfigurationCreate',
        'connector': 'int',
        'external_id': 'str',
        'name': 'str',
        'payment_page_endpoint': 'str',
        'processor_external_id': 'str',
        'refund_configuration': 'PaymentAppRefundConfigurationCreate',
    }

    attribute_map = {
        'authorization_timeout_in_minutes': 'authorizationTimeoutInMinutes','completion_configuration': 'completionConfiguration','connector': 'connector','external_id': 'externalId','name': 'name','payment_page_endpoint': 'paymentPageEndpoint','processor_external_id': 'processorExternalId','refund_configuration': 'refundConfiguration',
    }

    
    _authorization_timeout_in_minutes = None
    _completion_configuration = None
    _connector = None
    _external_id = None
    _name = None
    _payment_page_endpoint = None
    _processor_external_id = None
    _refund_configuration = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.authorization_timeout_in_minutes = kwargs.get('authorization_timeout_in_minutes')

        self.completion_configuration = kwargs.get('completion_configuration', None)
        self.connector = kwargs.get('connector')

        self.external_id = kwargs.get('external_id')

        self.name = kwargs.get('name')

        self.payment_page_endpoint = kwargs.get('payment_page_endpoint')

        self.processor_external_id = kwargs.get('processor_external_id')

        self.refund_configuration = kwargs.get('refund_configuration', None)
        

    
    @property
    def authorization_timeout_in_minutes(self):
        """Gets the authorization_timeout_in_minutes of this PaymentAppConnectorCreationRequest.

            When the transaction is not authorized within this timeout the transaction is considered as failed.

        :return: The authorization_timeout_in_minutes of this PaymentAppConnectorCreationRequest.
        :rtype: int
        """
        return self._authorization_timeout_in_minutes

    @authorization_timeout_in_minutes.setter
    def authorization_timeout_in_minutes(self, authorization_timeout_in_minutes):
        """Sets the authorization_timeout_in_minutes of this PaymentAppConnectorCreationRequest.

            When the transaction is not authorized within this timeout the transaction is considered as failed.

        :param authorization_timeout_in_minutes: The authorization_timeout_in_minutes of this PaymentAppConnectorCreationRequest.
        :type: int
        """
        if authorization_timeout_in_minutes is None:
            raise ValueError("Invalid value for `authorization_timeout_in_minutes`, must not be `None`")

        self._authorization_timeout_in_minutes = authorization_timeout_in_minutes
    
    @property
    def completion_configuration(self):
        """Gets the completion_configuration of this PaymentAppConnectorCreationRequest.

            The completion configuration allows the connector to support deferred completions on a transaction. If it is not provided the connector will not process transactions in deferred mode.

        :return: The completion_configuration of this PaymentAppConnectorCreationRequest.
        :rtype: PaymentAppCompletionConfigurationCreate
        """
        return self._completion_configuration

    @completion_configuration.setter
    def completion_configuration(self, completion_configuration):
        """Sets the completion_configuration of this PaymentAppConnectorCreationRequest.

            The completion configuration allows the connector to support deferred completions on a transaction. If it is not provided the connector will not process transactions in deferred mode.

        :param completion_configuration: The completion_configuration of this PaymentAppConnectorCreationRequest.
        :type: PaymentAppCompletionConfigurationCreate
        """

        self._completion_configuration = completion_configuration
    
    @property
    def connector(self):
        """Gets the connector of this PaymentAppConnectorCreationRequest.

            The ID of the connector identifies which connector that should be linked with this web app connector. The connector defines the payment method.

        :return: The connector of this PaymentAppConnectorCreationRequest.
        :rtype: int
        """
        return self._connector

    @connector.setter
    def connector(self, connector):
        """Sets the connector of this PaymentAppConnectorCreationRequest.

            The ID of the connector identifies which connector that should be linked with this web app connector. The connector defines the payment method.

        :param connector: The connector of this PaymentAppConnectorCreationRequest.
        :type: int
        """
        if connector is None:
            raise ValueError("Invalid value for `connector`, must not be `None`")

        self._connector = connector
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentAppConnectorCreationRequest.

            The external ID identifies the connector within the external system. It has to be unique per processor external ID and for any subsequent update the same ID must be sent.

        :return: The external_id of this PaymentAppConnectorCreationRequest.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentAppConnectorCreationRequest.

            The external ID identifies the connector within the external system. It has to be unique per processor external ID and for any subsequent update the same ID must be sent.

        :param external_id: The external_id of this PaymentAppConnectorCreationRequest.
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")
        if external_id is not None and len(external_id) > 40:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `40`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def name(self):
        """Gets the name of this PaymentAppConnectorCreationRequest.

            The name of the connector will be displayed within the user interfaces that the merchant is interacting with.

        :return: The name of this PaymentAppConnectorCreationRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentAppConnectorCreationRequest.

            The name of the connector will be displayed within the user interfaces that the merchant is interacting with.

        :param name: The name of this PaymentAppConnectorCreationRequest.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def payment_page_endpoint(self):
        """Gets the payment_page_endpoint of this PaymentAppConnectorCreationRequest.

            The payment page endpoint URL will be invoked by the buyer to carry out the authorization of the payment.

        :return: The payment_page_endpoint of this PaymentAppConnectorCreationRequest.
        :rtype: str
        """
        return self._payment_page_endpoint

    @payment_page_endpoint.setter
    def payment_page_endpoint(self, payment_page_endpoint):
        """Sets the payment_page_endpoint of this PaymentAppConnectorCreationRequest.

            The payment page endpoint URL will be invoked by the buyer to carry out the authorization of the payment.

        :param payment_page_endpoint: The payment_page_endpoint of this PaymentAppConnectorCreationRequest.
        :type: str
        """
        if payment_page_endpoint is None:
            raise ValueError("Invalid value for `payment_page_endpoint`, must not be `None`")

        self._payment_page_endpoint = payment_page_endpoint
    
    @property
    def processor_external_id(self):
        """Gets the processor_external_id of this PaymentAppConnectorCreationRequest.

            The external ID of the processor identifies the processor to which this connector belongs to. The processor cannot be changed once it has been set on a connector.

        :return: The processor_external_id of this PaymentAppConnectorCreationRequest.
        :rtype: str
        """
        return self._processor_external_id

    @processor_external_id.setter
    def processor_external_id(self, processor_external_id):
        """Sets the processor_external_id of this PaymentAppConnectorCreationRequest.

            The external ID of the processor identifies the processor to which this connector belongs to. The processor cannot be changed once it has been set on a connector.

        :param processor_external_id: The processor_external_id of this PaymentAppConnectorCreationRequest.
        :type: str
        """
        if processor_external_id is None:
            raise ValueError("Invalid value for `processor_external_id`, must not be `None`")
        if processor_external_id is not None and len(processor_external_id) > 40:
            raise ValueError("Invalid value for `processor_external_id`, length must be less than or equal to `40`")
        if processor_external_id is not None and len(processor_external_id) < 1:
            raise ValueError("Invalid value for `processor_external_id`, length must be greater than or equal to `1`")

        self._processor_external_id = processor_external_id
    
    @property
    def refund_configuration(self):
        """Gets the refund_configuration of this PaymentAppConnectorCreationRequest.

            The refund configuration allows the connector to support refunds on transactions. In case no refund configuration is provided the connector will not support refunds.

        :return: The refund_configuration of this PaymentAppConnectorCreationRequest.
        :rtype: PaymentAppRefundConfigurationCreate
        """
        return self._refund_configuration

    @refund_configuration.setter
    def refund_configuration(self, refund_configuration):
        """Sets the refund_configuration of this PaymentAppConnectorCreationRequest.

            The refund configuration allows the connector to support refunds on transactions. In case no refund configuration is provided the connector will not support refunds.

        :param refund_configuration: The refund_configuration of this PaymentAppConnectorCreationRequest.
        :type: PaymentAppRefundConfigurationCreate
        """

        self._refund_configuration = refund_configuration
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppConnectorCreationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppConnectorCreationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentTerminalTransactionSum:

    swagger_types = {
    
        'brand': 'str',
        'dcc_tip_amount': 'float',
        'dcc_transaction_amount': 'float',
        'dcc_transaction_count': 'int',
        'id': 'int',
        'product': 'str',
        'transaction_amount': 'float',
        'transaction_count': 'int',
        'transaction_currency': 'str',
        'transaction_tip_amount': 'float',
        'version': 'int',
    }

    attribute_map = {
        'brand': 'brand','dcc_tip_amount': 'dccTipAmount','dcc_transaction_amount': 'dccTransactionAmount','dcc_transaction_count': 'dccTransactionCount','id': 'id','product': 'product','transaction_amount': 'transactionAmount','transaction_count': 'transactionCount','transaction_currency': 'transactionCurrency','transaction_tip_amount': 'transactionTipAmount','version': 'version',
    }

    
    _brand = None
    _dcc_tip_amount = None
    _dcc_transaction_amount = None
    _dcc_transaction_count = None
    _id = None
    _product = None
    _transaction_amount = None
    _transaction_count = None
    _transaction_currency = None
    _transaction_tip_amount = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.brand = kwargs.get('brand', None)
        self.dcc_tip_amount = kwargs.get('dcc_tip_amount', None)
        self.dcc_transaction_amount = kwargs.get('dcc_transaction_amount', None)
        self.dcc_transaction_count = kwargs.get('dcc_transaction_count', None)
        self.id = kwargs.get('id', None)
        self.product = kwargs.get('product', None)
        self.transaction_amount = kwargs.get('transaction_amount', None)
        self.transaction_count = kwargs.get('transaction_count', None)
        self.transaction_currency = kwargs.get('transaction_currency', None)
        self.transaction_tip_amount = kwargs.get('transaction_tip_amount', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def brand(self):
        """Gets the brand of this PaymentTerminalTransactionSum.

            

        :return: The brand of this PaymentTerminalTransactionSum.
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this PaymentTerminalTransactionSum.

            

        :param brand: The brand of this PaymentTerminalTransactionSum.
        :type: str
        """

        self._brand = brand
    
    @property
    def dcc_tip_amount(self):
        """Gets the dcc_tip_amount of this PaymentTerminalTransactionSum.

            

        :return: The dcc_tip_amount of this PaymentTerminalTransactionSum.
        :rtype: float
        """
        return self._dcc_tip_amount

    @dcc_tip_amount.setter
    def dcc_tip_amount(self, dcc_tip_amount):
        """Sets the dcc_tip_amount of this PaymentTerminalTransactionSum.

            

        :param dcc_tip_amount: The dcc_tip_amount of this PaymentTerminalTransactionSum.
        :type: float
        """

        self._dcc_tip_amount = dcc_tip_amount
    
    @property
    def dcc_transaction_amount(self):
        """Gets the dcc_transaction_amount of this PaymentTerminalTransactionSum.

            

        :return: The dcc_transaction_amount of this PaymentTerminalTransactionSum.
        :rtype: float
        """
        return self._dcc_transaction_amount

    @dcc_transaction_amount.setter
    def dcc_transaction_amount(self, dcc_transaction_amount):
        """Sets the dcc_transaction_amount of this PaymentTerminalTransactionSum.

            

        :param dcc_transaction_amount: The dcc_transaction_amount of this PaymentTerminalTransactionSum.
        :type: float
        """

        self._dcc_transaction_amount = dcc_transaction_amount
    
    @property
    def dcc_transaction_count(self):
        """Gets the dcc_transaction_count of this PaymentTerminalTransactionSum.

            

        :return: The dcc_transaction_count of this PaymentTerminalTransactionSum.
        :rtype: int
        """
        return self._dcc_transaction_count

    @dcc_transaction_count.setter
    def dcc_transaction_count(self, dcc_transaction_count):
        """Sets the dcc_transaction_count of this PaymentTerminalTransactionSum.

            

        :param dcc_transaction_count: The dcc_transaction_count of this PaymentTerminalTransactionSum.
        :type: int
        """

        self._dcc_transaction_count = dcc_transaction_count
    
    @property
    def id(self):
        """Gets the id of this PaymentTerminalTransactionSum.

            A unique identifier for the object.

        :return: The id of this PaymentTerminalTransactionSum.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentTerminalTransactionSum.

            A unique identifier for the object.

        :param id: The id of this PaymentTerminalTransactionSum.
        :type: int
        """

        self._id = id
    
    @property
    def product(self):
        """Gets the product of this PaymentTerminalTransactionSum.

            

        :return: The product of this PaymentTerminalTransactionSum.
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this PaymentTerminalTransactionSum.

            

        :param product: The product of this PaymentTerminalTransactionSum.
        :type: str
        """

        self._product = product
    
    @property
    def transaction_amount(self):
        """Gets the transaction_amount of this PaymentTerminalTransactionSum.

            

        :return: The transaction_amount of this PaymentTerminalTransactionSum.
        :rtype: float
        """
        return self._transaction_amount

    @transaction_amount.setter
    def transaction_amount(self, transaction_amount):
        """Sets the transaction_amount of this PaymentTerminalTransactionSum.

            

        :param transaction_amount: The transaction_amount of this PaymentTerminalTransactionSum.
        :type: float
        """

        self._transaction_amount = transaction_amount
    
    @property
    def transaction_count(self):
        """Gets the transaction_count of this PaymentTerminalTransactionSum.

            

        :return: The transaction_count of this PaymentTerminalTransactionSum.
        :rtype: int
        """
        return self._transaction_count

    @transaction_count.setter
    def transaction_count(self, transaction_count):
        """Sets the transaction_count of this PaymentTerminalTransactionSum.

            

        :param transaction_count: The transaction_count of this PaymentTerminalTransactionSum.
        :type: int
        """

        self._transaction_count = transaction_count
    
    @property
    def transaction_currency(self):
        """Gets the transaction_currency of this PaymentTerminalTransactionSum.

            

        :return: The transaction_currency of this PaymentTerminalTransactionSum.
        :rtype: str
        """
        return self._transaction_currency

    @transaction_currency.setter
    def transaction_currency(self, transaction_currency):
        """Sets the transaction_currency of this PaymentTerminalTransactionSum.

            

        :param transaction_currency: The transaction_currency of this PaymentTerminalTransactionSum.
        :type: str
        """

        self._transaction_currency = transaction_currency
    
    @property
    def transaction_tip_amount(self):
        """Gets the transaction_tip_amount of this PaymentTerminalTransactionSum.

            

        :return: The transaction_tip_amount of this PaymentTerminalTransactionSum.
        :rtype: float
        """
        return self._transaction_tip_amount

    @transaction_tip_amount.setter
    def transaction_tip_amount(self, transaction_tip_amount):
        """Sets the transaction_tip_amount of this PaymentTerminalTransactionSum.

            

        :param transaction_tip_amount: The transaction_tip_amount of this PaymentTerminalTransactionSum.
        :type: float
        """

        self._transaction_tip_amount = transaction_tip_amount
    
    @property
    def version(self):
        """Gets the version of this PaymentTerminalTransactionSum.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentTerminalTransactionSum.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentTerminalTransactionSum.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentTerminalTransactionSum.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentTerminalTransactionSum, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentTerminalTransactionSum):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



import unittest

from constants import (
    API_CONFIG,
    SPACE_ID,
    get_transaction_create,
    FAKE_CARD_DATA,
    TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
    TEST_CUSTOMER_ID,
)

from wallee.api import (
    TransactionServiceApi,
    CardProcessingServiceApi,
    ChargeAttemptServiceApi
)
from wallee.models import (
    TransactionState,
    EntityQuery,
    EntityQueryFilter,
    EntityQueryFilterType,
    CriteriaOperator,
    TokenizationMode,
    TransactionCompletionBehavior,
    CustomersPresence,
)

class ChargeAttemptServiceTest(unittest.TestCase):
    """ChargeAttemptServiceApi tests"""

    def setUp(self):
        self.transaction_service = TransactionServiceApi(API_CONFIG)
        self.card_processing_service = CardProcessingServiceApi(API_CONFIG)
        self.charge_attempt_service = ChargeAttemptServiceApi(API_CONFIG)

    def tearDown(self):
        pass

    def test_search(self):
        """search() should find charge attempts by given criteria"""

        transaction_create = get_transaction_create()
        transaction_create.tokenization_mode = TokenizationMode.FORCE_CREATION
        transaction_create.customers_presence = CustomersPresence.NOT_PRESENT
        transaction_create.completion_behavior = TransactionCompletionBehavior.COMPLETE_DEFERRED

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=transaction_create)
        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        self.assertEqual(
            TransactionState.AUTHORIZED,
            transaction_processed.state,
            "State must be AUTHORIZED",
        )

        entity_query_filter = EntityQueryFilter(
            field_name="charge.transaction.id",
            value=transaction.id,
            type=EntityQueryFilterType.LEAF,
            operator=CriteriaOperator.EQUALS,
        )
        entity_query = EntityQuery(filter=entity_query_filter)

        attempts_found = self.charge_attempt_service.search(
            space_id=SPACE_ID, query=entity_query)

        self.assertTrue(len(attempts_found) > 0)
        for attempt in attempts_found:
            self.assertEqual(transaction.id, attempt.linked_transaction)

    # TODO write more API tests


if __name__ == "__main__":
    unittest.main(failfast=True)



# coding: utf-8
import pprint
import six
from enum import Enum



class InternalTransferBankTransaction:

    swagger_types = {
    
        'id': 'int',
        'linked_space_id': 'int',
        'source_bank_transaction': 'BankTransaction',
        'target_bank_transaction': 'BankTransaction',
        'version': 'int',
    }

    attribute_map = {
        'id': 'id','linked_space_id': 'linkedSpaceId','source_bank_transaction': 'sourceBankTransaction','target_bank_transaction': 'targetBankTransaction','version': 'version',
    }

    
    _id = None
    _linked_space_id = None
    _source_bank_transaction = None
    _target_bank_transaction = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.source_bank_transaction = kwargs.get('source_bank_transaction', None)
        self.target_bank_transaction = kwargs.get('target_bank_transaction', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def id(self):
        """Gets the id of this InternalTransferBankTransaction.

            A unique identifier for the object.

        :return: The id of this InternalTransferBankTransaction.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InternalTransferBankTransaction.

            A unique identifier for the object.

        :param id: The id of this InternalTransferBankTransaction.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this InternalTransferBankTransaction.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this InternalTransferBankTransaction.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this InternalTransferBankTransaction.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this InternalTransferBankTransaction.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def source_bank_transaction(self):
        """Gets the source_bank_transaction of this InternalTransferBankTransaction.

            

        :return: The source_bank_transaction of this InternalTransferBankTransaction.
        :rtype: BankTransaction
        """
        return self._source_bank_transaction

    @source_bank_transaction.setter
    def source_bank_transaction(self, source_bank_transaction):
        """Sets the source_bank_transaction of this InternalTransferBankTransaction.

            

        :param source_bank_transaction: The source_bank_transaction of this InternalTransferBankTransaction.
        :type: BankTransaction
        """

        self._source_bank_transaction = source_bank_transaction
    
    @property
    def target_bank_transaction(self):
        """Gets the target_bank_transaction of this InternalTransferBankTransaction.

            

        :return: The target_bank_transaction of this InternalTransferBankTransaction.
        :rtype: BankTransaction
        """
        return self._target_bank_transaction

    @target_bank_transaction.setter
    def target_bank_transaction(self, target_bank_transaction):
        """Sets the target_bank_transaction of this InternalTransferBankTransaction.

            

        :param target_bank_transaction: The target_bank_transaction of this InternalTransferBankTransaction.
        :type: BankTransaction
        """

        self._target_bank_transaction = target_bank_transaction
    
    @property
    def version(self):
        """Gets the version of this InternalTransferBankTransaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this InternalTransferBankTransaction.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InternalTransferBankTransaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this InternalTransferBankTransaction.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(InternalTransferBankTransaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, InternalTransferBankTransaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class TenantDatabase:

    swagger_types = {
    
        'id': 'int',
        'name': 'str',
        'version': 'int',
    }

    attribute_map = {
        'id': 'id','name': 'name','version': 'version',
    }

    
    _id = None
    _name = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def id(self):
        """Gets the id of this TenantDatabase.

            A unique identifier for the object.

        :return: The id of this TenantDatabase.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TenantDatabase.

            A unique identifier for the object.

        :param id: The id of this TenantDatabase.
        :type: int
        """

        self._id = id
    
    @property
    def name(self):
        """Gets the name of this TenantDatabase.

            The name used to identify the database.

        :return: The name of this TenantDatabase.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TenantDatabase.

            The name used to identify the database.

        :param name: The name of this TenantDatabase.
        :type: str
        """
        if name is not None and len(name) > 200:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")

        self._name = name
    
    @property
    def version(self):
        """Gets the version of this TenantDatabase.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this TenantDatabase.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this TenantDatabase.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this TenantDatabase.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TenantDatabase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TenantDatabase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



import unittest

from constants import (
    API_CONFIG,
    SPACE_ID,
    get_transaction_create,
    TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
    FAKE_CARD_DATA
)

from wallee.api import (
    TransactionServiceApi,
    CardProcessingServiceApi,
    TransactionCompletionServiceApi,
)

from wallee.models import (
    TokenizationMode,
    TransactionCompletionBehavior,
    CustomersPresence,
    EntityQueryFilter,
    EntityQueryFilterType,
    CriteriaOperator,
    EntityQuery,
    TransactionState,
    TransactionCompletionState
)


class TransactionCompletionServiceTest(unittest.TestCase):
    """TransactionCompletionServiceApi tests"""

    def setUp(self):
        self.transaction_service = TransactionServiceApi(API_CONFIG)
        self.transaction_completion_service = TransactionCompletionServiceApi(
            API_CONFIG)
        self.card_processing_service = CardProcessingServiceApi(API_CONFIG)

    def tearDown(self):
        pass

    def __get_deferred_transaction_create(self):
        transaction_create = get_transaction_create()
        transaction_create.tokenization_mode = TokenizationMode.FORCE_CREATION
        transaction_create.customers_presence = CustomersPresence.NOT_PRESENT
        transaction_create.completion_behavior = TransactionCompletionBehavior.COMPLETE_DEFERRED
        return transaction_create

    def test_complete_offline(self):
        """complete_offline() should complete transaction offline (completion is NOT forwarded to processor)"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=self.__get_deferred_transaction_create())

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        self.assertEqual(
            TransactionState.AUTHORIZED,
            transaction_processed.state,
            "State must be AUTHORIZED",
        )

        transaction_completion = self.transaction_completion_service.complete_offline(
            space_id=SPACE_ID, id=transaction_processed.id)

        self.assertEqual(
            TransactionCompletionState.SUCCESSFUL,
            transaction_completion.state,
            "State must be SUCCESSFUL",
        )

    def test_complete_online(self):
        """complete_online() should complete transaction online (completion is forwarded to processor)"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=self.__get_deferred_transaction_create())

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        self.assertEqual(
            TransactionState.AUTHORIZED,
            transaction_processed.state,
            "State must be AUTHORIZED",
        )

        transaction_completion = self.transaction_completion_service.complete_online(
            space_id=SPACE_ID, id=transaction_processed.id)

        self.assertEqual(
            TransactionCompletionState.SUCCESSFUL,
            transaction_completion.state,
            "State must be SUCCESSFUL",
        )

    def test_read(self):
        """read() should read details of transaction completion by id"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=self.__get_deferred_transaction_create())

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        self.assertEqual(
            TransactionState.AUTHORIZED,
            transaction_processed.state,
            "State must be AUTHORIZED",
        )

        transaction_completion = self.transaction_completion_service.complete_online(
            space_id=SPACE_ID, id=transaction_processed.id)

        transaction_read = self.transaction_completion_service.read(
            space_id=SPACE_ID, id=transaction_completion.id)

        self.assertIsNotNone(transaction_read, "Return data must not be None.")

        self.assertEqual(transaction_completion.id,
                         transaction_read.id, "Transaction ids must match", )

    def test_count(self):
        """count() should count transaction completions based on provided criteria"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=self.__get_deferred_transaction_create())

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        transaction_completion = self.transaction_completion_service.complete_online(
            space_id=SPACE_ID, id=transaction_processed.id)

        criteria = EntityQueryFilter(
            field_name="id",
            value=transaction_completion.id,
            type=EntityQueryFilterType.LEAF,
            operator=CriteriaOperator.EQUALS
        )

        count = self.transaction_completion_service.count(
            space_id=SPACE_ID, filter=criteria)

        self.assertEqual(1, count, "Count of completions should be 1", )

    def test_search(self):
        """search() should find transaction completions based on provided criteria"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=self.__get_deferred_transaction_create())

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        transaction_completion = self.transaction_completion_service.complete_online(
            space_id=SPACE_ID, id=transaction_processed.id)

        criteria = EntityQuery(
            filter=EntityQueryFilter(
                field_name="id",
                value=transaction_completion.id,
                type=EntityQueryFilterType.LEAF,
                operator=CriteriaOperator.EQUALS
            )
        )

        found_completions = self.transaction_completion_service.search(
            space_id=SPACE_ID, query=criteria)

        for compl in found_completions:
            self.assertEqual(transaction_completion.id,
                             compl.id, "Completion id should match")


if __name__ == "__main__":
    unittest.main(failfast=True)



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractWebhookListenerUpdate:

    swagger_types = {
    
        'enable_payload_signature_and_state': 'bool',
        'entity_states': 'list[str]',
        'name': 'str',
        'notify_every_change': 'bool',
        'state': 'CreationEntityState',
    }

    attribute_map = {
        'enable_payload_signature_and_state': 'enablePayloadSignatureAndState','entity_states': 'entityStates','name': 'name','notify_every_change': 'notifyEveryChange','state': 'state',
    }

    
    _enable_payload_signature_and_state = None
    _entity_states = None
    _name = None
    _notify_every_change = None
    _state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.enable_payload_signature_and_state = kwargs.get('enable_payload_signature_and_state', None)
        self.entity_states = kwargs.get('entity_states', None)
        self.name = kwargs.get('name', None)
        self.notify_every_change = kwargs.get('notify_every_change', None)
        self.state = kwargs.get('state', None)
        

    
    @property
    def enable_payload_signature_and_state(self):
        """Gets the enable_payload_signature_and_state of this AbstractWebhookListenerUpdate.

            Whether signature header and state property are enabled in webhook payload.

        :return: The enable_payload_signature_and_state of this AbstractWebhookListenerUpdate.
        :rtype: bool
        """
        return self._enable_payload_signature_and_state

    @enable_payload_signature_and_state.setter
    def enable_payload_signature_and_state(self, enable_payload_signature_and_state):
        """Sets the enable_payload_signature_and_state of this AbstractWebhookListenerUpdate.

            Whether signature header and state property are enabled in webhook payload.

        :param enable_payload_signature_and_state: The enable_payload_signature_and_state of this AbstractWebhookListenerUpdate.
        :type: bool
        """

        self._enable_payload_signature_and_state = enable_payload_signature_and_state
    
    @property
    def entity_states(self):
        """Gets the entity_states of this AbstractWebhookListenerUpdate.

            The entity's target states that are to be monitored.

        :return: The entity_states of this AbstractWebhookListenerUpdate.
        :rtype: list[str]
        """
        return self._entity_states

    @entity_states.setter
    def entity_states(self, entity_states):
        """Sets the entity_states of this AbstractWebhookListenerUpdate.

            The entity's target states that are to be monitored.

        :param entity_states: The entity_states of this AbstractWebhookListenerUpdate.
        :type: list[str]
        """

        self._entity_states = entity_states
    
    @property
    def name(self):
        """Gets the name of this AbstractWebhookListenerUpdate.

            The name used to identify the webhook listener.

        :return: The name of this AbstractWebhookListenerUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractWebhookListenerUpdate.

            The name used to identify the webhook listener.

        :param name: The name of this AbstractWebhookListenerUpdate.
        :type: str
        """
        if name is not None and len(name) > 50:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `50`")

        self._name = name
    
    @property
    def notify_every_change(self):
        """Gets the notify_every_change of this AbstractWebhookListenerUpdate.

            Whether every update of the entity or only state changes are to be monitored.

        :return: The notify_every_change of this AbstractWebhookListenerUpdate.
        :rtype: bool
        """
        return self._notify_every_change

    @notify_every_change.setter
    def notify_every_change(self, notify_every_change):
        """Sets the notify_every_change of this AbstractWebhookListenerUpdate.

            Whether every update of the entity or only state changes are to be monitored.

        :param notify_every_change: The notify_every_change of this AbstractWebhookListenerUpdate.
        :type: bool
        """

        self._notify_every_change = notify_every_change
    
    @property
    def state(self):
        """Gets the state of this AbstractWebhookListenerUpdate.

            The object's current state.

        :return: The state of this AbstractWebhookListenerUpdate.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractWebhookListenerUpdate.

            The object's current state.

        :param state: The state of this AbstractWebhookListenerUpdate.
        :type: CreationEntityState
        """

        self._state = state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractWebhookListenerUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractWebhookListenerUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class TransactionInvoice(TransactionAwareEntity):

    swagger_types = {
    
        'amount': 'float',
        'billing_address': 'Address',
        'completion': 'TransactionCompletion',
        'created_on': 'datetime',
        'derecognized_by': 'int',
        'derecognized_on': 'datetime',
        'due_on': 'datetime',
        'environment': 'Environment',
        'external_id': 'str',
        'language': 'str',
        'line_items': 'list[LineItem]',
        'merchant_reference': 'str',
        'outstanding_amount': 'float',
        'paid_on': 'datetime',
        'planned_purge_date': 'datetime',
        'space_view_id': 'int',
        'state': 'TransactionInvoiceState',
        'tax_amount': 'float',
        'time_zone': 'str',
        'version': 'int',
    }

    attribute_map = {
        'amount': 'amount','billing_address': 'billingAddress','completion': 'completion','created_on': 'createdOn','derecognized_by': 'derecognizedBy','derecognized_on': 'derecognizedOn','due_on': 'dueOn','environment': 'environment','external_id': 'externalId','language': 'language','line_items': 'lineItems','merchant_reference': 'merchantReference','outstanding_amount': 'outstandingAmount','paid_on': 'paidOn','planned_purge_date': 'plannedPurgeDate','space_view_id': 'spaceViewId','state': 'state','tax_amount': 'taxAmount','time_zone': 'timeZone','version': 'version',
    }

    
    _amount = None
    _billing_address = None
    _completion = None
    _created_on = None
    _derecognized_by = None
    _derecognized_on = None
    _due_on = None
    _environment = None
    _external_id = None
    _language = None
    _line_items = None
    _merchant_reference = None
    _outstanding_amount = None
    _paid_on = None
    _planned_purge_date = None
    _space_view_id = None
    _state = None
    _tax_amount = None
    _time_zone = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.billing_address = kwargs.get('billing_address', None)
        self.completion = kwargs.get('completion', None)
        self.created_on = kwargs.get('created_on', None)
        self.derecognized_by = kwargs.get('derecognized_by', None)
        self.derecognized_on = kwargs.get('derecognized_on', None)
        self.due_on = kwargs.get('due_on', None)
        self.environment = kwargs.get('environment', None)
        self.external_id = kwargs.get('external_id', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.merchant_reference = kwargs.get('merchant_reference', None)
        self.outstanding_amount = kwargs.get('outstanding_amount', None)
        self.paid_on = kwargs.get('paid_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.tax_amount = kwargs.get('tax_amount', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.version = kwargs.get('version', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def amount(self):
        """Gets the amount of this TransactionInvoice.

            

        :return: The amount of this TransactionInvoice.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this TransactionInvoice.

            

        :param amount: The amount of this TransactionInvoice.
        :type: float
        """

        self._amount = amount
    
    @property
    def billing_address(self):
        """Gets the billing_address of this TransactionInvoice.

            

        :return: The billing_address of this TransactionInvoice.
        :rtype: Address
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this TransactionInvoice.

            

        :param billing_address: The billing_address of this TransactionInvoice.
        :type: Address
        """

        self._billing_address = billing_address
    
    @property
    def completion(self):
        """Gets the completion of this TransactionInvoice.

            

        :return: The completion of this TransactionInvoice.
        :rtype: TransactionCompletion
        """
        return self._completion

    @completion.setter
    def completion(self, completion):
        """Sets the completion of this TransactionInvoice.

            

        :param completion: The completion of this TransactionInvoice.
        :type: TransactionCompletion
        """

        self._completion = completion
    
    @property
    def created_on(self):
        """Gets the created_on of this TransactionInvoice.

            The date on which the invoice is created on.

        :return: The created_on of this TransactionInvoice.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this TransactionInvoice.

            The date on which the invoice is created on.

        :param created_on: The created_on of this TransactionInvoice.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def derecognized_by(self):
        """Gets the derecognized_by of this TransactionInvoice.

            The id of the user which marked the invoice as derecognized.

        :return: The derecognized_by of this TransactionInvoice.
        :rtype: int
        """
        return self._derecognized_by

    @derecognized_by.setter
    def derecognized_by(self, derecognized_by):
        """Sets the derecognized_by of this TransactionInvoice.

            The id of the user which marked the invoice as derecognized.

        :param derecognized_by: The derecognized_by of this TransactionInvoice.
        :type: int
        """

        self._derecognized_by = derecognized_by
    
    @property
    def derecognized_on(self):
        """Gets the derecognized_on of this TransactionInvoice.

            The date on which the invoice is marked as derecognized.

        :return: The derecognized_on of this TransactionInvoice.
        :rtype: datetime
        """
        return self._derecognized_on

    @derecognized_on.setter
    def derecognized_on(self, derecognized_on):
        """Sets the derecognized_on of this TransactionInvoice.

            The date on which the invoice is marked as derecognized.

        :param derecognized_on: The derecognized_on of this TransactionInvoice.
        :type: datetime
        """

        self._derecognized_on = derecognized_on
    
    @property
    def due_on(self):
        """Gets the due_on of this TransactionInvoice.

            The date on which the invoice should be paid on.

        :return: The due_on of this TransactionInvoice.
        :rtype: datetime
        """
        return self._due_on

    @due_on.setter
    def due_on(self, due_on):
        """Sets the due_on of this TransactionInvoice.

            The date on which the invoice should be paid on.

        :param due_on: The due_on of this TransactionInvoice.
        :type: datetime
        """

        self._due_on = due_on
    
    @property
    def environment(self):
        """Gets the environment of this TransactionInvoice.

            

        :return: The environment of this TransactionInvoice.
        :rtype: Environment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this TransactionInvoice.

            

        :param environment: The environment of this TransactionInvoice.
        :type: Environment
        """

        self._environment = environment
    
    @property
    def external_id(self):
        """Gets the external_id of this TransactionInvoice.

            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.

        :return: The external_id of this TransactionInvoice.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this TransactionInvoice.

            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.

        :param external_id: The external_id of this TransactionInvoice.
        :type: str
        """
        if external_id is not None and len(external_id) > 100:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def language(self):
        """Gets the language of this TransactionInvoice.

            The language that is linked to the object.

        :return: The language of this TransactionInvoice.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this TransactionInvoice.

            The language that is linked to the object.

        :param language: The language of this TransactionInvoice.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this TransactionInvoice.

            

        :return: The line_items of this TransactionInvoice.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this TransactionInvoice.

            

        :param line_items: The line_items of this TransactionInvoice.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def merchant_reference(self):
        """Gets the merchant_reference of this TransactionInvoice.

            

        :return: The merchant_reference of this TransactionInvoice.
        :rtype: str
        """
        return self._merchant_reference

    @merchant_reference.setter
    def merchant_reference(self, merchant_reference):
        """Sets the merchant_reference of this TransactionInvoice.

            

        :param merchant_reference: The merchant_reference of this TransactionInvoice.
        :type: str
        """
        if merchant_reference is not None and len(merchant_reference) > 100:
            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")

        self._merchant_reference = merchant_reference
    
    @property
    def outstanding_amount(self):
        """Gets the outstanding_amount of this TransactionInvoice.

            The outstanding amount indicates how much the buyer owes the merchant. A negative amount indicates that the invoice is overpaid.

        :return: The outstanding_amount of this TransactionInvoice.
        :rtype: float
        """
        return self._outstanding_amount

    @outstanding_amount.setter
    def outstanding_amount(self, outstanding_amount):
        """Sets the outstanding_amount of this TransactionInvoice.

            The outstanding amount indicates how much the buyer owes the merchant. A negative amount indicates that the invoice is overpaid.

        :param outstanding_amount: The outstanding_amount of this TransactionInvoice.
        :type: float
        """

        self._outstanding_amount = outstanding_amount
    
    @property
    def paid_on(self):
        """Gets the paid_on of this TransactionInvoice.

            The date on which the invoice is marked as paid. Eventually this date lags behind of the actual paid date.

        :return: The paid_on of this TransactionInvoice.
        :rtype: datetime
        """
        return self._paid_on

    @paid_on.setter
    def paid_on(self, paid_on):
        """Sets the paid_on of this TransactionInvoice.

            The date on which the invoice is marked as paid. Eventually this date lags behind of the actual paid date.

        :param paid_on: The paid_on of this TransactionInvoice.
        :type: datetime
        """

        self._paid_on = paid_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this TransactionInvoice.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this TransactionInvoice.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this TransactionInvoice.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this TransactionInvoice.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this TransactionInvoice.

            

        :return: The space_view_id of this TransactionInvoice.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this TransactionInvoice.

            

        :param space_view_id: The space_view_id of this TransactionInvoice.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this TransactionInvoice.

            The object's current state.

        :return: The state of this TransactionInvoice.
        :rtype: TransactionInvoiceState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this TransactionInvoice.

            The object's current state.

        :param state: The state of this TransactionInvoice.
        :type: TransactionInvoiceState
        """

        self._state = state
    
    @property
    def tax_amount(self):
        """Gets the tax_amount of this TransactionInvoice.

            

        :return: The tax_amount of this TransactionInvoice.
        :rtype: float
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """Sets the tax_amount of this TransactionInvoice.

            

        :param tax_amount: The tax_amount of this TransactionInvoice.
        :type: float
        """

        self._tax_amount = tax_amount
    
    @property
    def time_zone(self):
        """Gets the time_zone of this TransactionInvoice.

            

        :return: The time_zone of this TransactionInvoice.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this TransactionInvoice.

            

        :param time_zone: The time_zone of this TransactionInvoice.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def version(self):
        """Gets the version of this TransactionInvoice.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this TransactionInvoice.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this TransactionInvoice.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this TransactionInvoice.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TransactionInvoice, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TransactionInvoice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class AnalyticsQueryExecutionState(Enum):
    
    PROCESSING = "PROCESSING"
    PROCESSED = "PROCESSED"
    FAILED = "FAILED"
    CANCELED = "CANCELED"




# coding: utf-8
import pprint
import six
from enum import Enum



class SpaceView:

    swagger_types = {
    
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'space': 'Space',
        'state': 'CreationEntityState',
        'version': 'int',
    }

    attribute_map = {
        'id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','planned_purge_date': 'plannedPurgeDate','space': 'space','state': 'state','version': 'version',
    }

    
    _id = None
    _linked_space_id = None
    _name = None
    _planned_purge_date = None
    _space = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.space = kwargs.get('space', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def id(self):
        """Gets the id of this SpaceView.

            A unique identifier for the object.

        :return: The id of this SpaceView.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SpaceView.

            A unique identifier for the object.

        :param id: The id of this SpaceView.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SpaceView.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this SpaceView.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SpaceView.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this SpaceView.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this SpaceView.

            The space view name is used internally to identify the space view in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this SpaceView.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SpaceView.

            The space view name is used internally to identify the space view in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this SpaceView.
        :type: str
        """
        if name is not None and len(name) > 200:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")
        if name is not None and len(name) < 3:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `3`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SpaceView.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this SpaceView.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SpaceView.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this SpaceView.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def space(self):
        """Gets the space of this SpaceView.

            The space to which the view belongs to.

        :return: The space of this SpaceView.
        :rtype: Space
        """
        return self._space

    @space.setter
    def space(self, space):
        """Sets the space of this SpaceView.

            The space to which the view belongs to.

        :param space: The space of this SpaceView.
        :type: Space
        """

        self._space = space
    
    @property
    def state(self):
        """Gets the state of this SpaceView.

            The object's current state.

        :return: The state of this SpaceView.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SpaceView.

            The object's current state.

        :param state: The state of this SpaceView.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this SpaceView.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this SpaceView.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SpaceView.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this SpaceView.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SpaceView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SpaceView):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class ShopifyIntegrationSubscriptionAppVersion(Enum):
    
    BASIC = "BASIC"
    SUBSCRIPTION = "SUBSCRIPTION"
    API_2019_07 = "API_2019_07"

